@@ -1,15 +1,18 @@
+
+#  FoXPath, tools for processing FoXPath test suites,
+#  by Martin Keegan, Mark Brough and Ben Webb
+
+#  Copyright (C) 2013  Martin Keegan
+#
+#  This programme is free software; you may redistribute and/or modify
+#  it under the terms of the GNU Affero General Public License v3.0
+
 import re
 import itertools
 import mapping
 
 class TestSyntaxError(Exception): pass
 
-comment = re.compile('#')
-blank = re.compile('^$')
-
-def ignore_line(line):
-    return bool(comment.match(line) or blank.match(line))
-
 def generate_test_functions(tests):
     mappings = mapping.generate_mappings()
 
@@ -21,9 +24,6 @@ def generate_test_functions(tests):
 
     test_functions = {}
 
-    tests = itertools.ifilter(lambda test: test.test_level == 1, tests)
-    tests = itertools.ifilter(lambda test: not ignore_line(test.name), tests)
-
     def function_for_test(test):
         line = test.name
 
